# 📋 📘 Boostnote Markdown CheatSheet - Preview!


The missing markdown feature cheat sheet for [Boostnote](https://boostnote.io/).  
It tries to give a short summary of all formatting options which are available in Boostnote.

---
:warning: This is the **Preview Page** to see how it's rendered.

:point_right: Open the [Cheat Sheet](BOOSTNOTE_MARKDOWN_CHEAT_SHEET.md) to see the code.

:u5408: [Chinese Version](BOOSTNOTE_MARKDOWN_CHEAT_SHEET_zh_cn.md)

---

### :information_source: How to add it to Boostnote
1. Open the [RAW](https://raw.githubusercontent.com/TobseF/boostnote-markdown-cheatsheet/master/BOOSTNOTE_MARKDOWN_CHEAT_SHEET.md) version of the cheat sheet. 
2. Copy it with <kbd>crtl</kbd> + <kbd>a</kbd> and <kbd>crtl</kbd> + <kbd>c</kbd>
3. Create an empty _Markdown Note_ in Bosstnote paste it with  
   <kbd>crtl</kbd> + <kbd>shift</kbd> + <kbd>v</kbd>  
   (The *shift* is important to skip escaping)
---

<!-- toc -->

- [Text Formatting](#Text-Formatting)
  * [Emphasis](#Emphasis)
  * [Abbreviation](#Abbreviation)
  * [Superscript](#Superscript)
  * [Link](#Link)
  * [Check box](#Check-box)
  * [Quotation](#Quotation)
  * [Footnotes](#Footnotes)
  * [Html](#Html)
  * [Emoticons](#Emoticons)
  * [Smart Arrows](#Smart-Arrows)
  * [Keystrokes](#Keystrokes)
  * [Source Code](#Source-Code)
- [Structuring](#Structuring)
  * [List](#List)
  * [Definition list](#Definition-list)
  * [Table](#Table)
  * [Block](#Block)
  * [Fold](#Fold)
  * [Horizontal line](#Horizontal-line)
  * [Admonition](#Admonition)
- [Image](#Image)
  * [Gallery](#Gallery)
- [Latex](#Latex)
- [Diagram Integrations](#Diagram-Integrations)
  * [Flowchart](#Flowchart)
  * [Sequence](#Sequence)
  * [mermaid](#mermaid)
  * [Chart](#Chart)
  * [Ditaa](#Ditaa)
  * [Plant UML](#Plant-UML)
    + [Class Diagram](#Class-Diagram)
    + [Activity Diagram](#Activity-Diagram)
    + [Sequence Diagram](#Sequence-Diagram)
    + [MindMap](#MindMap)
    + [Work Breakdown Structure](#Work-Breakdown-Structure)
    + [Gantt Diagram](#Gantt-Diagram)

<!-- tocstop -->

> *Table of Contens generated by:*
> `Shortcut:` [[Shift]]+[[ctrl]]+[[T]]
> `Menu:`  _File / Generate / Update Markdown TOC_

## Text Formatting

### Emphasis
*Italic type*  
**Bold**  
~~Negative~~  
`highlighted`  

### Abbreviation
![mermaid](attachments/abbreviation.png?raw=true)

### Superscript
![mermaid](attachments/superscript.png?raw=true)

### Link
`Simple link`:  https://en.wikipedia.org/wiki/Microsoft_Notepad  
`Named link`:   [Boostnote](https://boostnote.io)  
`Tooltip link`: [Hover Me](https://boostnote.io "A cool tooltip")  
`Auto linking`: [google.com](https://google.com)  
`Jump to line`: [Go to line 200](:line:200)

### Check box
- [x] Task 1
- [ ] Task 2

### Quotation
> Quotation
> Quotation Quotation

### Footnotes
Here is a footnote reference, <sup>[1](#myFootNote)</sup>
and another <sup>[2](#anotherFootNote)</sup>.

### Html
<span style="color:green">Green Text</span>
<span style="color:yellow">Yellow Text</span>
<u>underlined</u>
> HTML only works if you enable:
> Menu: _Preferences / Interface / Preview / Sanitization / Allow dangerous html tags_

### Emoticons
Emoji by shortcode: :books: :memo: :eyes:  
Emoji by Unicode:   📚 📝 👀  
[complete emojy list](https://www.webpagefx.com/tools/emoji-cheat-sheet/)

### Smart Arrows
--> →  
<-- ←  
<-> ↔  
==> ⇒  
<== ⇐  
<==> ⇔  

> Smart arrows only work if you enable:  
> Menu: _Preferences / Interface / Preview / Sanitization / Convert textual arrows to beautiful signs_  
> ⚠ This will interfere with using HTML comments in your Markdown.

### Keystrokes
![latex](attachments/keystrokes.png?raw=true)

### Source Code

``` js
Render: function () {
  Return (
    <Div className = “commentBox”>
      <H1> Comments </ h1>
      <CommentList data = {this.state.data} />
      <CommentForm onCommentSubmit = {this.handleCommentSubmit} />
    </Div>
  );
}
```

## Structuring

### List
* List 1
* List 2
1. First ordered list item
 Second line
2. Another item

### Definition list

![flowchart](attachments/definition_list.png?raw=true)

### Table
| Tables        | Are           | Cool  |
| :------------ |:-------------:| -----:|
| col 3 is      | right-aligned | $1600 |
| col 2 is      | centered      |   $12 |
| zebra stripes | are neat      |    $1 |
|             |          Grouping           ||

![flowchart](attachments/table.png?raw=true)

Markdown | Less | Pretty
--- | --- | ---
*Still* | `renders` | **nicely**
1 | 2 | 3

> There must be at least 3 dashes separating each header cell.
The outer pipes (|) are optional, and you don't need to make the
raw Markdown line up prettily. You can also use inline Markdown.

### Block
	Some Infor First Line - Lorem ipsum dolor sit amet, consetetur sadipscing eli
	Some Infor Second Line - Lorem ipsum dolor sit amet, consetetur sadipscing eli
	Some Infor Third Line - Lorem ipsum dolor sit amet, consetetur sadipscing eli

### Fold
<details><summary>Boostnote is a notepad corresponding to markdown notation, which is a tool for organizing and sharing information.</summary>
- Features - <br>
· Search function to find memos in one shot
· Supports markdown notation <br>
· Support for Mac, Windows, Linux, iOS, Android <br>
· Export and import to Plain text (.txt), Markdown (.md) format <br>
· Supports PDF saving <br>
· Can be used offline <br>
· Synchronize to dropbox etc. with setting <br>
* Supports theme colors and numerous fonts<br>
</details>
</details>

### Horizontal line
Horizontal lines have various ways of writing.
* * *
***
---

### Admonition

![admonition](attachments/admonition.png?raw=true)

## Image

![images](attachments/images.png?raw=true)

### Gallery

![chart](attachments/gallery.png?raw=true)

## Latex

![latex](attachments/latex.png?raw=true)

## Diagram Integrations

### Flowchart

![flowchart](attachments/flowchart.png?raw=true)

### Sequence

![sequence](attachments/ditaa_sequence.png?raw=true)

### [mermaid](https://mermaidjs.github.io/)

![mermaid](attachments/mermaid.png?raw=true)


### Chart

![chart](attachments/chart.png?raw=true)

### [Ditaa](http://ditaa.sourceforge.net/)

![ditaa 1](attachments/ditaa_1.png?raw=true)

![ditaa 2](attachments/ditaa_2.png?raw=true)


### [Plant UML](http://plantuml.com/)

#### [Class Diagram](https://plantuml.com/class-diagram)
![plantuml 1](attachments/plantuml_class_diagram.png?raw=true)

#### [Activity Diagram](https://plantuml.com/activity-diagram-beta)
![plantuml 2](attachments/plantuml_activity_diagram.png?raw=true)

#### [Sequence Diagram](https://plantuml.com/sequence-diagram)
![plantuml 3](attachments/plantuml_sequence_diagram.png?raw=true)

#### [MindMap](https://plantuml.com/mindmap-diagram)
![plantuml 4](attachments/plantuml_mindmap.png?raw=true)

#### [Work Breakdown Structure](https://plantuml.com/wbs-diagram)
![plantuml 5](attachments/plantuml_work_bbreakdown_structure.png?raw=true)

#### [Gantt Diagram](https://plantuml.com/gantt-diagram)
![plantuml 6](attachments/plantuml_gantt.png?raw=true)



---

<a name="myFootNote">1</a>: Here’s one with multiple blocks.

<a name="anotherFootNote">2</a>: Subsequent paragraphs are indented to show that they belong to the previous footnote.
